xbatcher: Batch Generation from Xarray Datasets
===============================================

|Build Status| |codecov| |docs| |pypi| |conda-forge| |license|


Xbatcher is a small library for iterating xarray DataArrays in batches. The
goal is to make it easy to feed xarray datasets to machine learning libraries
such as PyTorch_ or TensorFlow_. View the |docs| for more info.

.. _TensorFlow: https://www.tensorflow.org/

.. _PyTorch: https://pytorch.org/


.. |Build Status| image:: https://github.com/xarray-contrib/xbatcher/workflows/CI/badge.svg
   :target: https://github.com/xarray-contrib/xbatcher/actions
   :alt: github actions build status
.. |codecov| image:: https://codecov.io/gh/xarray-contrib/xbatcher/branch/main/graph/badge.svg
   :target: https://codecov.io/gh/xarray-contrib/xbatcher
   :alt: code coverage
.. |docs| image:: http://readthedocs.org/projects/xbatcher/badge/?version=latest
   :target: http://xbatcher.readthedocs.org/en/latest/?badge=latest
   :alt: docs
.. |pypi| image:: https://img.shields.io/pypi/v/xbatcher.svg
   :target: https://pypi.python.org/pypi/xbatcher
   :alt: pypi
.. |conda-forge| image:: https://img.shields.io/conda/vn/conda-forge/xbatcher.svg
   :target: https://anaconda.org/conda-forge/xbatcher
   :alt: conda-forge
.. |license| image:: https://img.shields.io/github/license/xarray-contrib/xbatcher.svg
   :target: https://github.com/xarray-contrib/xbatcher
   :alt: license
